---
hide:
    - toc
---
# 🇫🇴 Faroese

See the [leaderboard page](/leaderboards) for more information about all the columns.

/// tab | Generative Leaderboard
<p>
  A generative leaderboard for Faroese is not available yet, as the necessary datasets
  are not yet available.
</p>
///

/// tab | NLU Leaderboard
    select: True
<iframe title="" aria-label="Table" id="datawrapper-chart-Z51mu" src="https://datawrapper.dwcdn.net/FuCo1" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="737" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r=0;r<e.length;r++)if(e[r].contentWindow===a.source){var i=a.data["datawrapper-height"][t]+"px";e[r].style.height=i}}}))}();
</script>
///
